"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const purify_ts_1 = require("purify-ts");
const memoize_1 = require("../memoize");
const git_config_path_1 = __importDefault(require("git-config-path"));
const parse_git_config_1 = __importDefault(require("parse-git-config"));
const parse_github_url_1 = __importDefault(require("parse-github-url"));
function _globalGitConfig() {
    return parse_git_config_1.default.sync({ path: git_config_path_1.default('global') });
}
exports.globalGitConfig = memoize_1.memoize(_globalGitConfig);
function _localGitConfig(root) {
    return parse_git_config_1.default.sync({ cwd: root });
}
exports.localGitConfig = memoize_1.memoize(_localGitConfig);
function gitUsername(config) {
    const githubUsername = purify_ts_1.Maybe
        .fromNullable(config.github)
        .chainNullable(github => github.user);
    const gitlabUsername = purify_ts_1.Maybe
        .fromNullable(config.gitlab)
        .chainNullable(gitlab => gitlab.user);
    return githubUsername.alt(gitlabUsername);
}
exports.gitUsername = gitUsername;
function gitFullName(config) {
    return purify_ts_1.Maybe.fromNullable(config.user)
        .chainNullable(user => user.name);
}
exports.gitFullName = gitFullName;
function gitEmail(config) {
    return purify_ts_1.Maybe.fromNullable(config.user)
        .chainNullable(user => user.email);
}
exports.gitEmail = gitEmail;
function scopedPackageName(scope, packageNameKebabCase) {
    return scope.length > 0
        ? `@${scope}/${packageNameKebabCase}`.replace(/^@+/, '@')
        : packageNameKebabCase;
}
exports.scopedPackageName = scopedPackageName;
/* eslint-disable @typescript-eslint/no-explicit-any */
function gitRemote(config) {
    return purify_ts_1.Maybe.fromNullable(config['remote "origin"'])
        .chainNullable(origin => origin.url)
        .map(url => parse_github_url_1.default(url))
        .map((parsed) => [
        'https://',
        parsed.host,
        '/',
        parsed.repo
    ].join(''));
}
exports.gitRemote = gitRemote;
/* eslint-enable @typescript-eslint/no-explicit-any */
function gitRepositoryWithoutSuffix(repository) {
    // DISCUSS: validating git url https://github.com/jonschlinkert/is-git-url
    return repository.replace(/.git$/, '');
}
exports.gitRepositoryWithoutSuffix = gitRepositoryWithoutSuffix;
function gitHost(repository) {
    return purify_ts_1.Maybe
        .fromNullable(repository.match(/.*(@|:\/\/)(.*?)(:|\/).*?\/.*?$/))
        .chainNullable(matches => matches[2]);
}
exports.gitHost = gitHost;
function gitGroup(repository) {
    return purify_ts_1.Maybe
        .fromNullable(repository.match(/.*[@/].*[:/](.*?)\/.*?$/))
        .chainNullable(matches => matches[1]);
}
exports.gitGroup = gitGroup;
//  LocalWords:  gitconfig packageNameKebabCase
